@@ -8,7 +8,19 @@ since it does not carry a checksum
 from pii_data.types import PiiEnum
 
 
-_SSN_PATTERN = r"(?!000|666|333)0*(?:[0-6][0-9][0-9]|[0-7][0-6][0-9]|[0-7][0-7][0-2])[-\ ](?!00)[0-9]{2}[-\ ](?!0000)[0-9]{4}"
+_SSN_PATTERN = r"""
+  \b
+  (?! 000 | 666 | 333 )
+  0*
+  (?: [0-6][0-9][0-9] | [0-7][0-6][0-9] | [0-7][0-7][0-2] )
+  [-\ ]
+  (?! 00)
+  [0-9]{2}
+  [-\ ]
+  (?! 0000)
+  [0-9]{4}
+  \b
+"""
 
 
 PII_TASKS = [
